# Statistics

Statistics for biological researches

## Confidence intervals for proportions

+ Arcsine (Fisher) method
+ Wilson method

## Titration
+ Spearman-Kärber method (titer)
+ Spearman-Kärber method (titer and confidence interval)
